@@ -5,5 +5,5 @@ plotPI <- function(X,g,type="pair",goi=NULL,mc=1,alg="Cnaive",col="black",highli
   ifelse(is.null(order), chOrder <- TRUE, chOrder <- order)
   probs <- estPI(X=X,g=g,type=type,goi=goi,mc=mc,order=chOrder,alg=alg)
 
-  plot(probs,...)
+  plot(probs,col=col,highlight=highlight,hlCol=hlCol,pch=pch,zoom=zoom,...)
 }
\ No newline at end of file
